package com.sinovatech.unicom.push;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.NameValuePair;
import org.apache.http.client.HttpClient;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;

import com.sinovatech.unicom.push.aes.AesEnum;
import com.sinovatech.unicom.push.aes.AesUtil;
import com.sinovatech.unicom.push.model.Message;
import com.sinovatech.unicom.push.model.UserInfo;
import com.sinovatech.unicom.push.request.PushReq;
import com.sinovatech.unicom.push.request.ReqBody;
import com.sinovatech.unicom.push.request.ReqHead;
import com.sinovatech.unicom.push.response.PushResp;
import com.sinovatech.unicom.push.utils.JsonUtil;
import com.sinovatech.unicom.push.utils.RandomUtil;

public class Model {

	private static String proceID = UUID.randomUUID().toString();

	/**
	 * Description:<br>
	 * 
	 * @param url
	 * @param formParams
	 * @param isResponse
	 *            是否需要响应
	 */
	private static String callHttpPost(String url,
			List<NameValuePair> formParams) {
		/* 创建HttpClient实例 */
		HttpClient client = new DefaultHttpClient();

		/* 创建一个post方法 */
		HttpPost httpPost = new HttpPost(url); // 创建HttpPost

		/* 执行post方法 */
		try {
			if (formParams != null) {
				httpPost.setEntity(new UrlEncodedFormEntity(formParams, "UTF-8"));
			}
			// 执行POST请求
			HttpResponse response = client.execute(httpPost);

			// 获取响应实体
			HttpEntity entity = response.getEntity();
			// 处理响应数据
			InputStream is = entity.getContent();
			BufferedReader in = new BufferedReader(new InputStreamReader(is,
					"UTF-8"));
			StringBuffer buffer = new StringBuffer();
			String line = "";
			while ((line = in.readLine()) != null) {
				buffer.append(line);
			}
			System.out.println(" 接口返回:" + buffer.toString());
			return buffer.toString();
		} catch (IOException e) {
			System.out.println("Fatal transport error: " + e.getMessage());
			e.printStackTrace();
		} catch (Exception e) {
			System.out.println("Fatal transport error: " + e.getMessage());
			e.printStackTrace();
		} finally {
			httpPost.releaseConnection();
		}
		return "";
	}

	// 注册测试
	public static void addMessageTest(String url) {
		List<NameValuePair> formParams = new ArrayList<NameValuePair>();
		formParams.add(new BasicNameValuePair("message", getAddMessageInfo()));
		String reponse = callHttpPost(url, formParams);
		responseProc(reponse);
	}

	public static void main(String[] args) {
		String url = "http://localhost:8080/pushweb/push";
		addMessageTest(url);
	}

	// 返回数据处理
	public static void responseProc(String message) {
		PushResp p = JsonUtil.jsonToObject(message, PushResp.class);
		if (p != null && p.getRespHead().getProcId() == proceID
				&& securityAuth(p)) {
			if ("0000".equals(p.getRespBody().getRespCode())) {
				System.out.println("发送消息成功");
			} else {
				System.out.println("发送消息失败;原因" + p.getRespBody().getRespDesp());
			}
		} else {
			System.out.println("请求失败!");
		}
	}

	/**
	 * 验证用户身份
	 * 
	 * @param pushReq
	 * @return
	 */
	public static boolean securityAuth(PushResp pushResp) {
		String srcCode = pushResp.getRespHead().getSrcCode();
		String aesIndex = pushResp.getRespHead().getAesIndex();
		String aesStr = pushResp.getRespHead().getAesStr();
		String newStr = srcCode
				+ AesEnum.getAesEnum(Integer.parseInt(aesIndex)).getAes();
		String newAes = AesUtil.aesEncrypt(newStr);
		if (newAes.equals(aesStr)) {
			return true;
		}
		return false;
	}

	// 新增消息
	public static String getAddMessageInfo() {

		PushReq pushReq = new PushReq();
		ReqHead reqHead = new ReqHead();
		ReqBody reqBody = new ReqBody();

		// 随机产生流水号
		reqHead.setProcId(proceID);
		// 加密字段前缀
		String srcCode = "UFIDA";
		// 0-9的随机数
		int index = RandomUtil.getRandom();
		reqHead.setSrcCode(srcCode);
		reqHead.setAesIndex(index + "");
		// 加密规则请查看文档
		reqHead.setAesStr(AesUtil.aesEncrypt(srcCode
				+ AesEnum.getAesEnum(index)));
		reqHead.setBipCode("PUSH0003");
		pushReq.setReqHead(reqHead);

		// 电话号码
		UserInfo userInfo = new UserInfo();
		userInfo.setUserMobile("18602304000");
		reqBody.setUserInfo(userInfo);

		List<Message> list = new ArrayList<Message>();
		Message m1 = new Message();
		m1.setContent("消息内容1");
		m1.setUrl("点击消息跳转到...url1");
		list.add(m1);

		Message m2 = new Message();
		m2.setContent("消息内容2");
		m2.setUrl("点击消息跳转到...url2");
		list.add(m2);

		reqBody.setMessages(list);
		pushReq.setReqBody(reqBody);

		// 数据转换
		return JsonUtil.getJson(pushReq);
	}
}
