package com.sinovatech.unicom.push.utils;

import java.io.IOException;

import org.codehaus.jackson.JsonGenerationException;
import org.codehaus.jackson.annotate.JsonAutoDetect.Visibility;
import org.codehaus.jackson.annotate.JsonMethod;
import org.codehaus.jackson.map.JsonMappingException;
import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.map.annotate.JsonSerialize.Inclusion;
import org.codehaus.jackson.type.TypeReference;

/**
 * JOSN处理方式
 * 
 * @author hefei
 * 
 */
public class JsonUtil {

	/**
	 * 由对象内容转换成JSON格式
	 * 
	 * @param obj
	 * @return
	 */
	@SuppressWarnings("deprecation")
	public static String getJson(Object obj) {

		ObjectMapper mapper = new ObjectMapper();
		/*
		 * 处理空字段内容信息
		 */
		mapper.getSerializationConfig().setSerializationInclusion(
				Inclusion.NON_NULL);
		mapper.getSerializationConfig()
				.disable(
						org.codehaus.jackson.map.SerializationConfig.Feature.WRITE_NULL_MAP_VALUES);
		mapper.configure(
				org.codehaus.jackson.map.SerializationConfig.Feature.FAIL_ON_EMPTY_BEANS,
				false);
		String str = null;
		try {
			str = mapper.writeValueAsString(obj);

		} catch (JsonGenerationException e) {
		} catch (JsonMappingException e) {
		} catch (IOException e) {
		}

		return str;
	}

	/**
	 * 由JSON格式转换成对象内容
	 * 
	 * @param obj
	 * @param jp
	 * @return
	 */
	public static Object parsentJson(Object obj, String jp) {

		ObjectMapper mapper = new ObjectMapper();
		/*
		 * 处理JSON字段名称不在对象中的问题
		 */
		mapper.setVisibility(JsonMethod.FIELD, Visibility.ANY);
		mapper.configure(
				org.codehaus.jackson.map.DeserializationConfig.Feature.FAIL_ON_UNKNOWN_PROPERTIES,
				false);

		try {
			obj = mapper.readValue(jp, obj.getClass());
		} catch (JsonGenerationException e) {
		} catch (JsonMappingException e) {
		} catch (IOException e) {
		}

		return obj;
	}

	/**
	 * @功能:String转换成对象
	 * @param obj
	 * @param jp
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public static <T> T jsonToObject(String jp, TypeReference<T> valueType) {
		ObjectMapper mapper = new ObjectMapper();
		/*
		 * 处理JSON字段名称不在对象中的问题
		 */
		mapper.setVisibility(JsonMethod.FIELD, Visibility.ANY);
		mapper.configure(
				org.codehaus.jackson.map.DeserializationConfig.Feature.FAIL_ON_UNKNOWN_PROPERTIES,
				false);

		T t = null;
		try {
			t = (T) mapper.readValue(jp, valueType);
		} catch (JsonGenerationException e) {
		} catch (JsonMappingException e) {
		} catch (IOException e) {
		}

		return t;
	}

	/**
	 * @功能:String转换成对象
	 * @param obj
	 * @param jp
	 * @return
	 */
	public static <T> T jsonToObject(String jp, Class<T> valueType) {
		ObjectMapper mapper = new ObjectMapper();
		/*
		 * 处理JSON字段名称不在对象中的问题
		 */
		mapper.setVisibility(JsonMethod.FIELD, Visibility.ANY);
		mapper.configure(
				org.codehaus.jackson.map.DeserializationConfig.Feature.FAIL_ON_UNKNOWN_PROPERTIES,
				false);

		T t = null;
		try {
			t = mapper.readValue(jp, valueType);
		} catch (JsonGenerationException e) {
		} catch (JsonMappingException e) {
		} catch (IOException e) {
		}

		return t;
	}

	public static void main(String[] args) {
	}
}
